/*******************************************************************************
* File Name: AO4.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AO4.h"

static AO4_BACKUP_STRUCT  AO4_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: AO4_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet AO4_SUT.c usage_AO4_Sleep_Wakeup
*******************************************************************************/
void AO4_Sleep(void)
{
    #if defined(AO4__PC)
        AO4_backup.pcState = AO4_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            AO4_backup.usbState = AO4_CR1_REG;
            AO4_USB_POWER_REG |= AO4_USBIO_ENTER_SLEEP;
            AO4_CR1_REG &= AO4_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(AO4__SIO)
        AO4_backup.sioState = AO4_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        AO4_SIO_REG &= (uint32)(~AO4_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: AO4_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to AO4_Sleep() for an example usage.
*******************************************************************************/
void AO4_Wakeup(void)
{
    #if defined(AO4__PC)
        AO4_PC = AO4_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            AO4_USB_POWER_REG &= AO4_USBIO_EXIT_SLEEP_PH1;
            AO4_CR1_REG = AO4_backup.usbState;
            AO4_USB_POWER_REG &= AO4_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(AO4__SIO)
        AO4_SIO_REG = AO4_backup.sioState;
    #endif
}


/* [] END OF FILE */
